/** 
 * 
 * Copyright 2004 Protique Ltd
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); 
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at 
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, 
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 * See the License for the specific language governing permissions and 
 * limitations under the License. 
 * 
 **/
package org.codehaus.activemq.service;

import org.codehaus.activemq.broker.BrokerClient;
import org.codehaus.activemq.filter.Filter;
import org.codehaus.activemq.message.ConsumerInfo;

import javax.jms.JMSException;
import java.util.Iterator;

/**
 * Represents a possibly persistent container of subscription objects
 *
 * @version $Revision: 1.4 $
 */
public interface SubscriptionContainer {

    /**
     * Gets the current subscription for the given consumerId if it is available
     *
     * @param consumerId
     * @return
     */
    public Subscription getSubscription(String consumerId);

    public Subscription removeSubscription(String consumerId);

    /**
     * @return an iterator through the subscriptions
     */
    public Iterator subscriptionIterator();


    /**
     * Creates a subscription (which could be a previous subscription
     * reconecting) and adds it to this container
     *
     * @param dispatcher
     * @param info
     * @param filter
     * @return
     */
    public Subscription makeSubscription(Dispatcher dispatcher, ConsumerInfo info, Filter filter);

    /**
     * There is only meant to be a single durable subscription open for a given clientID and subscriber name;
     * this method will check to ensure that a user doesn't try to subscribe twice for the same clientID
     * and subscriber name.
     *
     * @param client
     * @param info
     */
    public void checkForDuplicateDurableSubscription(BrokerClient client, ConsumerInfo info) throws JMSException;
}
