/** 
 * 
 * Copyright 2004 Protique Ltd
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); 
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at 
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, 
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 * See the License for the specific language governing permissions and 
 * limitations under the License. 
 * 
 **/
package org.codehaus.activemq.tool;

import javax.jms.DeliveryMode;
import javax.jms.Message;
import javax.jms.MessageProducer;
import java.util.Date;

/**
 * A simple tool for publishing messages
 *
 * @version $Revision: 1.6 $
 */
public class ProducerTool extends ToolSupport {

    protected MessageProducer producer;
    protected int messageCount = 10;
    protected long sleepTime = 0L;
    protected boolean verbose = true;

    public static void main(String[] args) {
        ProducerTool tool = new ProducerTool();
        if (args.length > 0) {
            tool.url = args[0];
        }
        if (args.length > 1) {
            tool.topic = args[1].equalsIgnoreCase("true");
        }
        if (args.length > 2) {
            tool.subject = args[2];
        }
        if (args.length > 3) {
            tool.durable = args[3].equalsIgnoreCase("true");
        }
        tool.run();
    }

    public void run() {
        try {
            System.out.println("Connecting to URL: " + url);
            System.out.println("Publishing to " + (topic ? "topic" : "queue") + ": " + subject);
            System.out.println("Using " + (durable ? "durable" : "non-durable") + " publishing");

            createSession();
            producer = session.createProducer(destination);
            if (durable) {
                producer.setDeliveryMode(DeliveryMode.PERSISTENT);
            }
            else {
                producer.setDeliveryMode(DeliveryMode.NON_PERSISTENT);
            }
            connection.start();

            sendLoop();

            System.out.println("Done.");
            close();
        }
        catch (Exception e) {
            System.out.println("Caught: " + e);
            e.printStackTrace();
        }
    }

    protected void sendLoop() throws Exception {
        for (int i = 0; i < messageCount; i++) {
            Message message = session.createTextMessage("Message: " + i + " sent at: " + new Date());

            if (verbose) {
                System.out.println("Sending message: " + message);
            }

            producer.send(message);
            Thread.sleep(sleepTime);
        }
    }
}